@@ -1,67 +1,69 @@
 package Devel::StackTrace;
+BEGIN {
+  $Devel::StackTrace::VERSION = '1.26';
+}
 
 use 5.006;
 
 use strict;
 use warnings;
 
+use Devel::StackTrace::Frame;
 use File::Spec;
 use Scalar::Util qw( blessed );
 
 use overload
-    '""' => \&as_string,
+    '""'     => \&as_string,
     fallback => 1;
 
-our $VERSION = '1.22';
-
-
-sub new
-{
+sub new {
     my $class = shift;
-    my %p = @_;
+    my %p     = @_;
 
     # Backwards compatibility - this parameter was renamed to no_refs
     # ages ago.
     $p{no_refs} = delete $p{no_object_refs}
         if exists $p{no_object_refs};
 
-    my $self =
-        bless { index  => undef,
-                frames => [],
-                raw    => [],
-                %p,
-              }, $class;
+    my $self = bless {
+        index  => undef,
+        frames => [],
+        raw    => [],
+        %p,
+    }, $class;
 
     $self->_record_caller_data();
 
     return $self;
 }
 
-sub _record_caller_data
-{
+sub _record_caller_data {
     my $self = shift;
 
     # We exclude this method by starting one frame back.
     my $x = 1;
-    while ( my @c =
-            do { package DB; @DB::args = (); caller($x++) } )
-    {
-        my @a = @DB::args;
+    while (
+        my @c
+        = do { package # the newline keeps dzil from adding a version here
+                   DB;
+BEGIN {
+  $DB::VERSION = '1.26';
+} @DB::args = (); caller( $x++ ) }
+        ) {
+        my @args = @DB::args;
 
-        if ( $self->{no_refs} )
-        {
-            @a = map { ref $_ ? $self->_ref_to_string($_) : $_ } @a;
+        if ( $self->{no_refs} ) {
+            @args = map { ref $_ ? $self->_ref_to_string($_) : $_ } @args;
         }
 
-        push @{ $self->{raw} },
-            { caller => \@c,
-              args   => \@a,
+        push @{ $self->{raw} }, {
+            caller => \@c,
+            args   => \@args,
             };
     }
 }
 
-sub _ref_to_string
-{
+sub _ref_to_string {
     my $self = shift;
     my $ref  = shift;
 
@@ -78,53 +80,49 @@ sub _ref_to_string
     return $@ ? overload::AddrRef($ref) : $str;
 }
 
-sub _make_frames
-{
+sub _make_frames {
     my $self = shift;
 
     my $filter = $self->_make_frame_filter;
 
     my $raw = delete $self->{raw};
-    for my $r ( @{$raw} )
-    {
+    for my $r ( @{$raw} ) {
         next unless $filter->($r);
 
         $self->_add_frame( $r->{caller}, $r->{args} );
     }
 }
 
-my $default_filter = sub { 1 };
-sub _make_frame_filter
-{
+my $default_filter = sub {1};
+
+sub _make_frame_filter {
     my $self = shift;
 
-    my (@i_pack_re, %i_class);
-    if ( $self->{ignore_package} )
-    {
-        $self->{ignore_package} =
-            [ $self->{ignore_package} ] unless UNIVERSAL::isa( $self->{ignore_package}, 'ARRAY' );
+    my ( @i_pack_re, %i_class );
+    if ( $self->{ignore_package} ) {
+        $self->{ignore_package} = [ $self->{ignore_package} ]
+            unless UNIVERSAL::isa( $self->{ignore_package}, 'ARRAY' );
 
-        @i_pack_re = map { ref $_ ? $_ : qr/^\Q$_\E$/ } @{ $self->{ignore_package} };
+        @i_pack_re
+            = map { ref $_ ? $_ : qr/^\Q$_\E$/ } @{ $self->{ignore_package} };
     }
 
     my $p = __PACKAGE__;
     push @i_pack_re, qr/^\Q$p\E$/;
 
-    if ( $self->{ignore_class} )
-    {
-        $self->{ignore_class} = [ $self->{ignore_class} ] unless ref $self->{ignore_class};
-        %i_class = map {$_ => 1} @{ $self->{ignore_class} };
+    if ( $self->{ignore_class} ) {
+        $self->{ignore_class} = [ $self->{ignore_class} ]
+            unless ref $self->{ignore_class};
+        %i_class = map { $_ => 1 } @{ $self->{ignore_class} };
     }
 
     my $user_filter = $self->{frame_filter};
 
-    return sub
-    {
+    return sub {
         return 0 if grep { $_[0]{caller}[0] =~ /$_/ } @i_pack_re;
         return 0 if grep { $_[0]{caller}[0]->isa($_) } keys %i_class;
 
-        if ( $user_filter )
-        {
+        if ($user_filter) {
             return $user_filter->( $_[0] );
         }
 
@@ -132,45 +130,45 @@ sub _make_frame_filter
     };
 }
 
-sub _add_frame
-{
+sub _add_frame {
     my $self = shift;
     my $c    = shift;
     my $args = shift;
 
     # eval and is_require are only returned when applicable under 5.00503.
-    push @$c, (undef, undef) if scalar @$c == 6;
+    push @$c, ( undef, undef ) if scalar @$c == 6;
 
-    if ( $self->{no_refs} )
-    {
+    if ( $self->{no_refs} ) {
     }
 
     push @{ $self->{frames} },
-        Devel::StackTraceFrame->new( $c, $args,
-                                     $self->{respect_overload}, $self->{max_arg_length} );
+        Devel::StackTrace::Frame->new(
+        $c,
+        $args,
+        $self->{respect_overload},
+        $self->{max_arg_length},
+        $self->{message},
+        $self->{indent}
+        );
 }
 
-sub next_frame
-{
+sub next_frame {
     my $self = shift;
 
     # reset to top if necessary.
     $self->{index} = -1 unless defined $self->{index};
 
     my @f = $self->frames();
-    if ( defined $f[ $self->{index} + 1 ] )
-    {
+    if ( defined $f[ $self->{index} + 1 ] ) {
         return $f[ ++$self->{index} ];
     }
-    else
-    {
+    else {
         $self->{index} = undef;
         return undef;
     }
 }
 
-sub prev_frame
-{
+sub prev_frame {
     my $self = shift;
 
     my @f = $self->frames();
@@ -178,26 +176,22 @@ sub prev_frame
     # reset to top if necessary.
     $self->{index} = scalar @f unless defined $self->{index};
 
-    if ( defined $f[ $self->{index} - 1 ] && $self->{index} >= 1 )
-    {
+    if ( defined $f[ $self->{index} - 1 ] && $self->{index} >= 1 ) {
         return $f[ --$self->{index} ];
     }
-    else
-    {
+    else {
         $self->{index} = undef;
         return undef;
     }
 }
 
-sub reset_pointer
-{
+sub reset_pointer {
     my $self = shift;
 
     $self->{index} = undef;
 }
 
-sub frames
-{
+sub frames {
     my $self = shift;
 
     $self->_make_frames() if $self->{raw};
@@ -205,31 +199,27 @@ sub frames
     return @{ $self->{frames} };
 }
 
-sub frame
-{
+sub frame {
     my $self = shift;
-    my $i = shift;
+    my $i    = shift;
 
     return unless defined $i;
 
     return ( $self->frames() )[$i];
 }
 
-sub frame_count
-{
+sub frame_count {
     my $self = shift;
 
-    return scalar ( $self->frames() );
+    return scalar( $self->frames() );
 }
 
-sub as_string
-{
+sub as_string {
     my $self = shift;
 
-    my $st = '';
+    my $st    = '';
     my $first = 1;
-    foreach my $f ( $self->frames() )
-    {
+    foreach my $f ( $self->frames() ) {
         $st .= $f->as_string($first) . "\n";
         $first = 0;
     }
@@ -237,152 +227,28 @@ sub as_string
     return $st;
 }
 
-# Hide from PAUSE
-package
-    Devel::StackTraceFrame;
-
-use strict;
-use warnings;
-
-our $VERSION = $Devel::StackTrace::VERSION;
-
-# Create accessor routines
-BEGIN
 {
-    no strict 'refs';
-    foreach my $f ( qw( package filename line subroutine hasargs
-                        wantarray evaltext is_require hints bitmask args ) )
-    {
-        next if $f eq 'args';
-        *{$f} = sub { my $s = shift; return $s->{$f} };
-    }
-}
+    package
+        Devel::StackTraceFrame;
 
-{
-    my @fields =
-        ( qw( package filename line subroutine hasargs wantarray
-              evaltext is_require hints bitmask ) );
-
-    sub new
-    {
-        my $proto = shift;
-        my $class = ref $proto || $proto;
-
-        my $self = bless {}, $class;
-
-        @{ $self }{ @fields } = @{$_[0]};
-
-        # fixup unix-style paths on win32
-        $self->{filename} = File::Spec->canonpath( $self->{filename} );
-
-        $self->{args} = $_[1];
-
-        $self->{respect_overload} = $_[2];
-
-        $self->{max_arg_length} = $_[3];
-
-        return $self;
-    }
-}
-
-sub args
-{
-    my $self = shift;
-
-    return @{ $self->{args} };
-}
-
-sub as_string
-{
-    my $self = shift;
-    my $first = shift;
-
-    my $sub = $self->subroutine;
-    # This code stolen straight from Carp.pm and then tweaked.  All
-    # errors are probably my fault  -dave
-    if ($first)
-    {
-        $sub = 'Trace begun';
-    }
-    else
-    {
-        # Build a string, $sub, which names the sub-routine called.
-        # This may also be "require ...", "eval '...' or "eval {...}"
-        if (my $eval = $self->evaltext)
-        {
-            if ($self->is_require)
-            {
-                $sub = "require $eval";
-            }
-            else
-            {
-                $eval =~ s/([\\\'])/\\$1/g;
-                $sub = "eval '$eval'";
-            }
-        }
-        elsif ($sub eq '(eval)')
-        {
-            $sub = 'eval {...}';
-        }
-
-        # if there are any arguments in the sub-routine call, format
-        # them according to the format variables defined earlier in
-        # this file and join them onto the $sub sub-routine string
-        #
-        # We copy them because they're going to be modified.
-        #
-        if ( my @a = $self->args )
-        {
-            for (@a)
-            {
-                # set args to the string "undef" if undefined
-                $_ = "undef", next unless defined $_;
-
-                # hack!
-                $_ = $self->Devel::StackTrace::_ref_to_string($_)
-                    if ref $_;
-
-                eval
-                {
-                    if ( $self->{max_arg_length}
-                         && length $_ > $self->{max_arg_length} )
-                    {
-                        substr( $_, $self->{max_arg_length} ) = '...';
-                    }
-
-                    s/'/\\'/g;
-
-                    # 'quote' arg unless it looks like a number
-                    $_ = "'$_'" unless /^-?[\d.]+$/;
-
-                    # print control/high ASCII chars as 'M-<char>' or '^<char>'
-                    s/([\200-\377])/sprintf("M-%c",ord($1)&0177)/eg;
-                    s/([\0-\37\177])/sprintf("^%c",ord($1)^64)/eg;
-                };
-
-                if ( my $e = $@ )
-                {
-                    $_ = $e =~ /malformed utf-8/i ? '(bad utf-8)' : '?';
-                }
-            }
-
-            # append ('all', 'the', 'arguments') to the $sub string
-            $sub .= '(' . join(', ', @a) . ')';
-            $sub .= ' called';
-        }
-    }
-
-    return "$sub at " . $self->filename . ' line ' . $self->line;
+    our @ISA = 'Devel::StackTrace::Frame';
 }
 
 1;
 
+# ABSTRACT: An object representing a stack trace
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-Devel::StackTrace - Stack trace and stack trace frame objects
+Devel::StackTrace - An object representing a stack trace
+
+=head1 VERSION
+
+version 1.26
 
 =head1 SYNOPSIS
 
@@ -393,25 +259,23 @@ Devel::StackTrace - Stack trace and stack trace frame objects
   print $trace->as_string; # like carp
 
   # from top (most recent) of stack to bottom.
-  while (my $frame = $trace->next_frame)
-  {
+  while (my $frame = $trace->next_frame) {
       print "Has args\n" if $frame->hasargs;
   }
 
   # from bottom (least recent) of stack to top.
-  while (my $frame = $trace->prev_frame)
-  {
+  while (my $frame = $trace->prev_frame) {
       print "Sub: ", $frame->subroutine, "\n";
   }
 
 =head1 DESCRIPTION
 
 The Devel::StackTrace module contains two classes, Devel::StackTrace
-and Devel::StackTraceFrame.  The goal of this object is to encapsulate
+and Devel::StackTrace::Frame.  The goal of this object is to encapsulate
 the information that can found through using the caller() function, as
 well as providing a simple interface to this data.
 
-The Devel::StackTrace object contains a set of Devel::StackTraceFrame
+The Devel::StackTrace object contains a set of Devel::StackTrace::Frame
 objects, one for each level of the stack.  The frames contain all the
 data available from C<caller()>.
 
@@ -428,13 +292,11 @@ Here's an example:
 
   foo();  # bottom frame is here
 
-  sub foo
-  {
+  sub foo {
      bar();
   }
 
-  sub bar
-  {
+  sub bar {
      Devel::StackTrace->new;  # top frame is here.
   }
 
@@ -506,11 +368,22 @@ each subroutine call. Setting this parameter causes it to truncate the
 argument's string representation if it is longer than this number of
 characters.
 
+=item * message => $string
+
+By default, Devel::StackTrace will use 'Trace begun' as the message for the
+first stack frame when you call C<as_string>. You can supply an alternative
+message using this option.
+
+=item * indent => $boolean
+
+If this parameter is true, each stack frame after the first will start with a
+tab character, just like C<Carp::confess()>.
+
 =back
 
 =item * $trace->next_frame
 
-Returns the next Devel::StackTraceFrame object down on the stack.  If
+Returns the next Devel::StackTrace::Frame object down on the stack.  If
 it hasn't been called before it returns the first frame.  It returns
 undef when it reaches the bottom of the stack and then resets its
 pointer so the next call to C<next_frame> or C<prev_frame> will work
@@ -518,7 +391,7 @@ properly.
 
 =item * $trace->prev_frame
 
-Returns the next Devel::StackTraceFrame object up on the stack.  If it
+Returns the next Devel::StackTrace::Frame object up on the stack.  If it
 hasn't been called before it returns the last frame.  It returns undef
 when it reaches the top of the stack and then resets its pointer so
 pointer so the next call to C<next_frame> or C<prev_frame> will work
@@ -532,7 +405,7 @@ appropriate.
 
 =item * $trace->frames
 
-Returns a list of Devel::StackTraceFrame objects.  The order they are
+Returns a list of Devel::StackTrace::Frame objects.  The order they are
 returned is from top (most recent) to bottom.
 
 =item * $trace->frame ($index)
@@ -552,44 +425,6 @@ quite similar to the Carp module's cluck/confess methods.
 
 =back
 
-=head1 Devel::StackTraceFrame METHODS
-
-See the L<caller> documentation for more information on what these
-methods return.
-
-=over 4
-
-=item * $frame->package
-
-=item * $frame->filename
-
-=item * $frame->line
-
-=item * $frame->subroutine
-
-=item * $frame->hasargs
-
-=item * $frame->wantarray
-
-=item * $frame->evaltext
-
-Returns undef if the frame was not part of an eval.
-
-=item * $frame->is_require
-
-Returns undef if the frame was not part of a require.
-
-=item * $frame->args
-
-Returns the arguments passed to the frame.  Note that any arguments
-that are references are returned as references, not copies.
-
-=item * $frame->hints
-
-=item * $frame->bitmask
-
-=back
-
 =head1 SUPPORT
 
 Please submit bugs to the CPAN RT system at
@@ -598,15 +433,18 @@ or via email at bug-devel-stacktrace@rt.cpan.org.
 
 =head1 AUTHOR
 
-Dave Rolsky, <autarch@urth.org>
+Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2000-2006 David Rolsky.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This software is Copyright (c) 2010 by Dave Rolsky.
 
-The full text of the license can be found in the LICENSE file included
-with this module.
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
